@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 
 
 class Order:
@@ -48,3 +47,5 @@ class RoleTitle:
     ALTERNATE = "Alternate"
     MEMBER = "Member"
     SUPERVISOR = "Supervisor"
+    SECRETARY = "Secretary"
+    VICEPRESIDENT = "Vice President"
