@@ -1,10 +1,11 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
+
+from __future__ import annotations
 
 import logging
 import re
 from dataclasses import dataclass
-from typing import Any, Callable, List, Optional, Type
+from typing import Any, Callable
 
 import requests
 from fireo.models import Model
@@ -38,14 +39,14 @@ class UniquenessValidation:
     """
 
     is_unique: bool
-    conflicting_models: List[Model]
+    conflicting_models: list[Model]
 
 
 #############################################################################
 # Field Validators
 
 
-def router_string_is_valid(router_string: Optional[str]) -> bool:
+def router_string_is_valid(router_string: str | None) -> bool:
     """
     Validate that the provided router string contains only lowercase alphabetic
     characters and optionally include a hyphen.
@@ -72,7 +73,35 @@ def router_string_is_valid(router_string: Optional[str]) -> bool:
     return False
 
 
-def email_is_valid(email: Optional[str]) -> bool:
+def time_duration_is_valid(time_duration: str | None) -> bool:
+    """
+    Validate that the provided time duration string is acceptable to FFmpeg.
+    The validator is unnecessarily limited to HH:MM:SS. The spec is a little
+    more flexible.
+
+    None is a valid option.
+
+    Parameters
+    ----------
+    time_duration: Optional[str]
+        The time duration to validate.
+
+    Returns
+    -------
+    status: bool
+        The validation status.
+    """
+    if time_duration is None:
+        return True
+
+    # HH:MM:SS
+    if re.match(r"^((((\d{1,2}:)?[0-5])?\d:)?[0-5])?\d$", time_duration):
+        return True
+
+    return False
+
+
+def email_is_valid(email: str | None) -> bool:
     """
     Validate that a valid email was provided.
 
@@ -97,7 +126,7 @@ def email_is_valid(email: Optional[str]) -> bool:
     return False
 
 
-def resource_exists(uri: Optional[str], **kwargs: Any) -> bool:
+def resource_exists(uri: str | None, **kwargs: Any) -> bool:  # noqa: C901
     """
     Validate that the URI provided points to an existing file.
 
@@ -107,13 +136,15 @@ def resource_exists(uri: Optional[str], **kwargs: Any) -> bool:
     ----------
     uri: Optional[str]
         The URI to validate resource existance for.
+    kwargs: Any
+        Any extra arguments needed for resource retrieval.
+        I.e. google_credentials_file.
 
     Returns
     -------
     status: bool
         The validation status.
     """
-
     if uri is None:
         return True
 
@@ -142,7 +173,7 @@ def resource_exists(uri: Optional[str], **kwargs: Any) -> bool:
     elif uri.startswith("http"):
         try:
             # Use HEAD request to check if remote resource exists
-            r = requests.head(uri, **kwargs)
+            r = requests.head(uri, verify=False)
 
             return r.status_code == requests.codes.ok
         except requests.exceptions.SSLError:
@@ -156,7 +187,7 @@ def resource_exists(uri: Optional[str], **kwargs: Any) -> bool:
         return False
 
 
-def create_constant_value_validator(constant_cls: Type) -> Callable[[str], bool]:
+def create_constant_value_validator(constant_cls: type) -> Callable[[str], bool]:
     """
     Create a validator func that validates a value is one of the valid values.
 
