@@ -1,12 +1,14 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
+
+from __future__ import annotations
 
 import logging
 from datetime import datetime, timedelta
 from importlib import import_module
 from operator import attrgetter
 from pathlib import Path
-from typing import Any, Callable, Dict, List, NamedTuple, Optional, Set, Tuple, Union
+from typing import Callable, NamedTuple
+from uuid import uuid4
 
 from aiohttp.client_exceptions import ClientResponseError
 from fireo.fields.errors import FieldValidationFailed, InvalidFieldType, RequiredField
@@ -15,14 +17,14 @@ from prefect import Flow, task
 from prefect.tasks.control_flow import case, merge
 from requests import ConnectionError
 
+from .. import __version__
 from ..database import constants as db_constants
 from ..database import functions as db_functions
 from ..database import models as db_models
 from ..database.validators import is_secure_uri, resource_exists, try_url
 from ..file_store import functions as fs_functions
-from ..sr_models import GoogleCloudSRModel, WebVTTSRModel
+from ..sr_models import WhisperModel
 from ..utils import constants_utils, file_utils
-from ..version import __version__
 from . import ingestion_models
 from .ingestion_models import EventIngestionModel, Session
 from .pipeline_config import EventGatherPipelineConfig
@@ -55,13 +57,12 @@ def import_get_events_func(func_path: str) -> Callable:
 
 def create_event_gather_flow(
     config: EventGatherPipelineConfig,
-    from_dt: Optional[Union[str, datetime]] = None,
-    to_dt: Optional[Union[str, datetime]] = None,
-    prefetched_events: Optional[List[EventIngestionModel]] = None,
+    from_dt: str | datetime | None = None,
+    to_dt: str | datetime | None = None,
+    prefetched_events: list[EventIngestionModel] | None = None,
 ) -> Flow:
     """
-    Provided a function to gather new event information, create the Prefect Flow object
-    to preview, run, or visualize.
+    Create the Prefect Flow object to preview, run, or visualize.
 
     Parameters
     ----------
@@ -75,6 +76,9 @@ def create_event_gather_flow(
         Optional ISO formatted string or datetime object to pass to the get_events
         function to act as the end point for event gathering.
         Default: None (now)
+    prefetched_events: Optional[List[EventIngestionModel]]
+        A list of events to process instead of running the scraper found in the config.
+        Default: None (use the scraper from the config)
 
     Returns
     -------
@@ -125,14 +129,14 @@ def create_event_gather_flow(
         log.info(f"Processing {len(events)} events.")
 
         for event in events:
-            session_processing_results: List[SessionProcessingResult] = []
+            session_processing_results: list[SessionProcessingResult] = []
             for session in event.sessions:
-                # Download video to local copy
-                resource_copy_filepath = resource_copy_task(uri=session.video_uri)
-
-                # Get unique session identifier
-                session_content_hash = get_session_content_hash(
-                    tmp_video_filepath=resource_copy_filepath,
+                # Download video to local copy making
+                # copy unique in case of shared session video
+                resource_copy_filepath = resource_copy_task(
+                    uri=session.video_uri,
+                    dst=f"{str(uuid4())}_temp",
+                    copy_suffix=True,
                 )
 
                 # Handle video conversion or non-secure resource
@@ -140,8 +144,8 @@ def create_event_gather_flow(
                 (
                     tmp_video_filepath,
                     session_video_hosted_url,
+                    session_content_hash,
                 ) = convert_video_and_handle_host(
-                    session_content_hash=session_content_hash,
                     video_filepath=resource_copy_filepath,
                     session=session,
                     credentials_file=config.google_credentials_file,
@@ -149,7 +153,7 @@ def create_event_gather_flow(
                 )
 
                 # Split audio and store
-                audio_uri = split_audio(
+                (audio_uri, local_audio_path,) = split_audio(
                     session_content_hash=session_content_hash,
                     tmp_video_filepath=tmp_video_filepath,
                     bucket=config.validated_gcs_bucket_name,
@@ -158,34 +162,24 @@ def create_event_gather_flow(
 
                 # Check caption uri
                 if session.caption_uri is not None:
-                    # If the caption doesn't exist, remove the property
-                    # This will result in Speech-to-Text being used instead
-                    #
-                    # The verify=False is passed to any http URIs
-                    # It was added because it's very common for SSL certs to be bad
-                    # See: https://github.com/CouncilDataProject/cdp-scrapers/pull/85
-                    # And: https://github.com/CouncilDataProject/seattle/runs/5957646032
-                    if not resource_exists(session.caption_uri, verify=False):
+                    # If the caption doesn't exist, remove the value
+                    if not resource_exists(session.caption_uri):
                         log.warning(
                             f"File not found using provided caption URI: "
                             f"'{session.caption_uri}'. "
-                            f"Removing the referenced caption URI and will process "
-                            f"the session using Speech-to-Text."
+                            f"Removing the referenced caption URI."
                         )
                         session.caption_uri = None
 
                 # Generate transcript
                 transcript_uri, transcript = generate_transcript(
-                    session_content_hash=session_content_hash,  # type: ignore
-                    audio_uri=audio_uri,  # type: ignore
+                    session_content_hash=session_content_hash,
+                    audio_path=local_audio_path,
                     session=session,
-                    event=event,
                     bucket=config.validated_gcs_bucket_name,
                     credentials_file=config.google_credentials_file,
-                    caption_new_speaker_turn_pattern=(
-                        config.caption_new_speaker_turn_pattern
-                    ),
-                    caption_confidence=config.caption_confidence,
+                    whisper_model_name=config.whisper_model_name,
+                    whisper_model_confidence=config.whisper_model_confidence,
                 )
 
                 # Generate thumbnails
@@ -201,10 +195,14 @@ def create_event_gather_flow(
                 resource_delete_task(
                     tmp_video_filepath, upstream_tasks=[audio_uri, static_thumbnail_uri]
                 )
+                resource_delete_task(
+                    local_audio_path,
+                    upstream_tasks=[transcript],
+                )
 
                 # Store all processed and provided data
                 session_processing_results.append(
-                    compile_session_processing_result(  # type: ignore
+                    compile_session_processing_result(
                         session=session,
                         session_video_hosted_url=session_video_hosted_url,
                         session_content_hash=session_content_hash,
@@ -228,7 +226,7 @@ def create_event_gather_flow(
 
 
 @task(max_retries=3, retry_delay=timedelta(seconds=120))
-def resource_copy_task(uri: str) -> str:
+def resource_copy_task(uri: str, dst: str = None, copy_suffix: bool = False) -> str:
     """
     Copy a file to a temporary location for processing.
 
@@ -236,6 +234,12 @@ def resource_copy_task(uri: str) -> str:
     ----------
     uri: str
         The URI to the file to copy.
+    dst: Optional[str]
+        An optional destination path for the file.
+        Default: None (place the file in the current directory with the same file name)
+    copy_suffix: bool
+        A bool for if the file suffix should be copied.
+        Default: False
 
     Returns
     -------
@@ -249,6 +253,8 @@ def resource_copy_task(uri: str) -> str:
     """
     return file_utils.resource_copy(
         uri=uri,
+        dst=dst,
+        copy_suffix=copy_suffix,
         overwrite=True,
     )
 
@@ -256,7 +262,7 @@ def resource_copy_task(uri: str) -> str:
 @task
 def resource_delete_task(uri: str) -> None:
     """
-    Remove local file
+    Remove local file.
 
     Parameters
     ----------
@@ -287,14 +293,13 @@ def get_session_content_hash(
     return file_utils.hash_file_contents(uri=tmp_video_filepath)
 
 
-@task(nout=2)
+@task(nout=3)
 def convert_video_and_handle_host(
-    session_content_hash: str,
     video_filepath: str,
     session: Session,
     credentials_file: str,
     bucket: str,
-) -> Tuple[str, str]:
+) -> tuple[str, str, str]:
     """
     Convert a video to MP4 (if necessary), upload it to the file store, and remove
     the original non-MP4 file that was resource copied.
@@ -324,19 +329,47 @@ def convert_video_and_handle_host(
     # Get file extension
     ext = Path(video_filepath).suffix.lower()
 
+    trim_video = bool(session.video_start_time or session.video_end_time)
+
     # Convert to mp4 if file isn't of approved web format
     cdp_will_host = False
     if ext not in [".mp4", ".webm"]:
         cdp_will_host = True
 
         # Convert video to mp4
-        mp4_filepath = file_utils.convert_video_to_mp4(video_filepath)
+        mp4_filepath = file_utils.convert_video_to_mp4(
+            video_filepath=Path(video_filepath),
+            start_time=session.video_start_time,
+            end_time=session.video_end_time,
+        )
 
-        # Remove old mkv file
         fs_functions.remove_local_file(video_filepath)
 
         # Update variable name for easier downstream typing
-        video_filepath = mp4_filepath
+        video_filepath = str(mp4_filepath)
+
+    # host trimmed videos because it's simpler than setting
+    # up transcription and playback ranges
+    elif trim_video:
+        cdp_will_host = True
+
+        # Trim video
+        trimmed_filepath = file_utils.clip_and_reformat_video(
+            video_filepath=Path(video_filepath),
+            start_time=session.video_start_time,
+            end_time=session.video_end_time,
+        )
+
+        fs_functions.remove_local_file(video_filepath)
+
+        # Update variable name for easier downstream typing
+        video_filepath = str(trimmed_filepath)
+
+    # Check if original session video uri is a m3u8
+    # We cant follow the normal coonvert video process from above
+    # because the m3u8 looks to the URI for all the chunks
+    elif session.video_uri.endswith(".m3u8"):
+        cdp_will_host = True
 
     # Store if the original host isn't https
     elif not is_secure_uri(session.video_uri):
@@ -358,6 +391,9 @@ def convert_video_and_handle_host(
     else:
         hosted_video_media_url = session.video_uri
 
+    # Get unique session identifier
+    session_content_hash = file_utils.hash_file_contents(uri=video_filepath)
+
     # Upload and swap if cdp is hosting
     if cdp_will_host:
         # Upload to gcsfs
@@ -375,16 +411,16 @@ def convert_video_and_handle_host(
             uri=hosted_video_uri,
         )
 
-    return video_filepath, hosted_video_media_url
+    return video_filepath, hosted_video_media_url, session_content_hash
 
 
-@task
+@task(nout=2)
 def split_audio(
     session_content_hash: str,
     tmp_video_filepath: str,
     bucket: str,
     credentials_file: str,
-) -> str:
+) -> tuple[str, str]:
     """
     Split the audio from a local video file.
 
@@ -403,12 +439,14 @@ def split_audio(
     -------
     audio_uri: str
         The URI to the uploaded audio file.
+    audio_local_path: str
+        The local path for the split audio.
     """
     # Check for existing audio
-    tmp_audio_filepath = f"{session_content_hash}-audio.wav"
+    local_audio_path = f"{session_content_hash}-audio.wav"
     audio_uri = fs_functions.get_file_uri(
         bucket=bucket,
-        filename=tmp_audio_filepath,
+        filename=local_audio_path,
         credentials_file=credentials_file,
     )
 
@@ -416,12 +454,12 @@ def split_audio(
     if audio_uri is None:
         # Split and store the audio in temporary file prior to upload
         (
-            tmp_audio_filepath,
+            local_audio_path,
             tmp_audio_log_out_filepath,
             tmp_audio_log_err_filepath,
         ) = file_utils.split_audio(
             video_read_path=tmp_video_filepath,
-            audio_save_path=tmp_audio_filepath,
+            audio_save_path=local_audio_path,
             overwrite=True,
         )
 
@@ -429,8 +467,7 @@ def split_audio(
         audio_uri = fs_functions.upload_file(
             credentials_file=credentials_file,
             bucket=bucket,
-            filepath=tmp_audio_filepath,
-            remove_local=True,
+            filepath=local_audio_path,
         )
         fs_functions.upload_file(
             credentials_file=credentials_file,
@@ -444,213 +481,49 @@ def split_audio(
             filepath=tmp_audio_log_err_filepath,
             remove_local=True,
         )
-
-    return audio_uri
-
-
-@task
-def construct_speech_to_text_phrases_context(event: EventIngestionModel) -> List[str]:
-    """
-    Construct a list of phrases to use for Google Speech-to-Text speech adaption.
-
-    See: https://cloud.google.com/speech-to-text/docs/speech-adaptation
-
-    Parameters
-    ----------
-    event: EventIngestionModel
-        The event details to pull context from.
-
-    Returns
-    -------
-    phrases: List[str]
-        Compiled list of strings to act as target weights for the model.
-
-    Notes
-    -----
-    Phrases are added in order of importance until GCP phrase limits are met.
-    The order of importance is defined as:
-    1. body name
-    2. event minutes item names
-    3. councilmember names
-    4. matter titles
-    5. councilmember role titles
-    """
-    # Note: Google Speech-to-Text allows max 500 phrases
-    phrases: Set[str] = set()
-
-    PHRASE_LIMIT = 500
-    CUM_CHAR_LIMIT = 9900
-
-    # In line def for get character count
-    # Google Speech-to-Text allows cumulative max 9900 characters
-    def _get_total_char_count(phrases: Set[str]) -> int:
-        chars = 0
-        for phrase in phrases:
-            chars += len(phrase)
-
-        return chars
-
-    def _get_if_added_sum(phrases: Set[str], next_addition: str) -> int:
-        current_len = _get_total_char_count(phrases)
-        return current_len + len(next_addition)
-
-    def _within_limit(phrases: Set[str]) -> bool:
-        return (
-            _get_total_char_count(phrases) < CUM_CHAR_LIMIT
-            and len(phrases) < PHRASE_LIMIT
+    # Download to ensure we have it for later
+    else:
+        local_audio_path = fs_functions.download_file(
+            credentials_file=credentials_file,
+            bucket=bucket,
+            remote_filepath=local_audio_path,
+            save_path=local_audio_path,
         )
 
-    # Get body name
-    if _within_limit(phrases):
-        if _get_if_added_sum(phrases, event.body.name) < CUM_CHAR_LIMIT:
-            phrases.add(event.body.name)
-
-    # Extras from event minutes items
-    if event.event_minutes_items is not None:
-        # Get minutes item name
-        for event_minutes_item in event.event_minutes_items:
-            if _within_limit(phrases):
-                if (
-                    _get_if_added_sum(phrases, event_minutes_item.minutes_item.name)
-                    < CUM_CHAR_LIMIT
-                ):
-                    phrases.add(event_minutes_item.minutes_item.name)
-
-        # Get councilmember names from sponsors and votes
-        for event_minutes_item in event.event_minutes_items:
-            if event_minutes_item.matter is not None:
-                if event_minutes_item.matter.sponsors is not None:
-                    for sponsor in event_minutes_item.matter.sponsors:
-                        if _within_limit(phrases):
-                            if (
-                                _get_if_added_sum(phrases, sponsor.name)
-                                < CUM_CHAR_LIMIT
-                            ):
-                                phrases.add(sponsor.name)
-            if event_minutes_item.votes is not None:
-                for vote in event_minutes_item.votes:
-                    if _within_limit(phrases):
-                        if (
-                            _get_if_added_sum(phrases, vote.person.name)
-                            < CUM_CHAR_LIMIT
-                        ):
-                            phrases.add(vote.person.name)
-
-        # Get matter titles
-        for event_minutes_item in event.event_minutes_items:
-            if event_minutes_item.matter is not None:
-                if _within_limit(phrases):
-                    if (
-                        _get_if_added_sum(phrases, event_minutes_item.matter.title)
-                        < CUM_CHAR_LIMIT
-                    ):
-                        phrases.add(event_minutes_item.matter.title)
-
-        # Get councilmember role titles from sponsors and votes
-        for event_minutes_item in event.event_minutes_items:
-            if event_minutes_item.matter is not None:
-                if event_minutes_item.matter.sponsors is not None:
-                    for sponsor in event_minutes_item.matter.sponsors:
-                        if sponsor.seat is not None:
-                            if sponsor.seat.roles is not None:
-                                for role in sponsor.seat.roles:
-                                    if (
-                                        _get_if_added_sum(phrases, role.title)
-                                        < CUM_CHAR_LIMIT
-                                    ):
-                                        phrases.add(role.title)
-            if event_minutes_item.votes is not None:
-                for vote in event_minutes_item.votes:
-                    if vote.person.seat is not None:
-                        if vote.person.seat.roles is not None:
-                            for role in vote.person.seat.roles:
-                                if _within_limit(phrases):
-                                    if (
-                                        _get_if_added_sum(phrases, role.title)
-                                        < CUM_CHAR_LIMIT
-                                    ):
-                                        phrases.add(role.title)
-
-    return list(phrases)
+    return audio_uri, local_audio_path
 
 
-@task
+@task(max_retries=2, retry_delay=timedelta(seconds=10))
 def use_speech_to_text_and_generate_transcript(
-    audio_uri: str,
-    credentials_file: str,
-    phrases: Optional[List[str]] = None,
+    audio_path: str,
+    model_name: str = "medium",
+    confidence: float | None = None,
 ) -> Transcript:
     """
-    Pass the audio URI through to Google Speech-to-Text.
+    Pass the audio path to the speech recognition model.
 
     Parameters
     ----------
-    audio_uri: str
-        The URI to the audio path. The audio must already be stored in a GCS bucket.
-    credentials_file: str
-        Path to Google Service Account Credentials JSON file.
-    phrases: Optional[List[str]]
-        A list of strings to feed as targets to the model.
+    audio_path: str
+        The URI to the audio path. The audio must be on the local machine.
+    model_name: str
+        The whisper model to use for transcription.
+    confidence: Optional[float]
+        The confidence to set the produce transcript to.
 
     Returns
     -------
     transcript: Transcript
         The generated Transcript object.
+
+    Notes
+    -----
+    See the sr_models.whisper.WhisperModel code for more details about
+    pass through params.
     """
     # Init model
-    model = GoogleCloudSRModel(credentials_file=credentials_file)
-    return model.transcribe(file_uri=audio_uri, phrases=phrases)
-
-
-@task
-def get_captions_and_generate_transcript(
-    caption_uri: str,
-    new_turn_pattern: Optional[str] = None,
-    confidence: Optional[float] = None,
-) -> Transcript:
-    """
-    Download (or copy) a WebVTT closed caption file and convert to CDP Transcript model.
-
-    Parameters
-    ----------
-    caption_uri: str
-        The URI to the caption file to transform into the transcript.
-    new_turn_pattern: Optional[str]
-        New speaker turn pattern to pass through to the WebVTT transformer.
-    confidence: Optional[float]
-        Confidence to provide to the produced transcript.
-
-    Returns
-    -------
-    transcript: Transcript
-        The produced transcript.
-    """
-    # If value provided, passthrough, otherwise ignore
-    model_kwargs: Dict[str, Any] = {}
-    if new_turn_pattern is not None:
-        model_kwargs["new_turn_pattern"] = new_turn_pattern
-    if confidence is not None:
-        model_kwargs["confidence"] = confidence
-
-    # Init model
-    model = WebVTTSRModel(**model_kwargs)
-
-    # Download or copy resource to local
-    caption_filename = caption_uri.split("/")[-1]
-    local_captions = file_utils.resource_copy(
-        uri=caption_uri,
-        dst=f"caption-transcribing-{caption_filename}",
-        overwrite=True,
-    )
-
-    # Transcribe
-    transcript = model.transcribe(file_uri=local_captions)
-
-    # Remove temp file
-    fs_functions.remove_local_file(local_captions)
-
-    # Return generated transcript
-    return transcript
+    model = WhisperModel(model_name=model_name, confidence=confidence)
+    return model.transcribe(file_uri=audio_path)
 
 
 @task(nout=2)
@@ -660,10 +533,9 @@ def finalize_and_archive_transcript(
     bucket: str,
     credentials_file: str,
     session: Session,
-) -> Tuple[str, Transcript]:
+) -> tuple[str, Transcript]:
     """
-    Finalizes metadata for a Transcript object, stores the transcript as JSON to object
-    storage and finally adds transcript and file objects to database.
+    Finalize and store the transcript to GCP.
 
     Parameters
     ----------
@@ -690,7 +562,7 @@ def finalize_and_archive_transcript(
 
     # Dump to JSON
     with open(transcript_save_path, "w") as open_resource:
-        open_resource.write(transcript.to_json())  # type: ignore
+        open_resource.write(transcript.to_json())
 
     # Store to file store
     transcript_file_uri = fs_functions.upload_file(
@@ -708,7 +580,7 @@ def check_for_existing_transcript(
     session_content_hash: str,
     bucket: str,
     credentials_file: str,
-) -> Tuple[str, Optional[str], Optional[Transcript], bool]:
+) -> tuple[str, str | None, Transcript | None, bool]:
     """
     Check and load any existing transcript object.
 
@@ -752,7 +624,7 @@ def check_for_existing_transcript(
     if transcript_exists:
         fs = GCSFileSystem(token=credentials_file)
         with fs.open(transcript_uri, "r") as open_resource:
-            transcript = Transcript.from_json(open_resource.read())  # type: ignore
+            transcript = Transcript.from_json(open_resource.read())
     else:
         transcript = None
 
@@ -761,14 +633,13 @@ def check_for_existing_transcript(
 
 def generate_transcript(
     session_content_hash: str,
-    audio_uri: str,
+    audio_path: str,
     session: Session,
-    event: EventIngestionModel,
     bucket: str,
     credentials_file: str,
-    caption_new_speaker_turn_pattern: Optional[str] = None,
-    caption_confidence: Optional[float] = None,
-) -> Tuple[str, Transcript]:
+    whisper_model_name: str = "medium",
+    whisper_model_confidence: float | None = None,
+) -> tuple[str, Transcript]:
     """
     Route transcript generation to the correct processing.
 
@@ -776,25 +647,19 @@ def generate_transcript(
     ----------
     session_content_hash: str
         The unique key (SHA256 hash of video content) for this session processing.
-    audio_uri: str
-        The URI to the audio file to generate a transcript from.
+    audio_path: str
+        The path to the audio file to generate a transcript from.
     session: Session
         The specific session details to be used in final transcript upload and
         archival.
-        Additionally, if a closed caption URI is available on the session object,
-        the transcript produced from this function will have been created using WebVTT
-        caption transform rather than Google Speech-to-Text.
-    event: EventIngestionModel
-        The parent event of the session. If no captions are available,
-        speech context phrases will be pulled from the whole event details.
     bucket: str
         The name of the GCS bucket to upload the produced audio to.
     credentials_file: str
-        Path to Google Service Account Credentials JSON file.
-    caption_new_speaker_turn_pattern: Optional[str]
-        Passthrough to sr_models.webvtt_sr_model.WebVTTSRModel.
-    caption_confidence: Optional[float]
-        Passthrough to sr_models.webvtt_sr_model.WebVTTSRModel.
+        Path to the GCS JSON credentials file.
+    whisper_model_name: str
+        The whisper model to use for transcription.
+    whisper_model_confidence: Optional[float]
+        The confidence to set the produce transcript to.
 
     Returns
     -------
@@ -817,22 +682,11 @@ def generate_transcript(
 
     # If no pre-existing transcript with the same parameters, generate
     with case(transcript_exists, False):
-        # If no captions, generate transcript with Google Speech-to-Text
-        if session.caption_uri is None:
-            phrases = construct_speech_to_text_phrases_context(event=event)
-            generated_transcript = use_speech_to_text_and_generate_transcript(
-                audio_uri=audio_uri,
-                credentials_file=credentials_file,
-                phrases=phrases,
-            )
-
-        # Process captions
-        else:
-            generated_transcript = get_captions_and_generate_transcript(
-                caption_uri=session.caption_uri,
-                new_turn_pattern=caption_new_speaker_turn_pattern,
-                confidence=caption_confidence,
-            )
+        generated_transcript = use_speech_to_text_and_generate_transcript(
+            audio_path=audio_path,
+            model_name=whisper_model_name,
+            confidence=whisper_model_confidence,
+        )
 
         # Add extra metadata and upload
         (
@@ -864,7 +718,7 @@ def generate_transcript(
     )
     result_transcript.name = "merge_in_memory_transcript"
 
-    return (result_transcript_uri, result_transcript)  # type: ignore
+    return (result_transcript_uri, result_transcript)
 
 
 @task(nout=2)
@@ -874,9 +728,9 @@ def generate_thumbnails(
     event: EventIngestionModel,
     bucket: str,
     credentials_file: str,
-) -> Tuple[str, str]:
+) -> tuple[str, str]:
     """
-    Creates static and hover thumbnails.
+    Create static and hover thumbnails.
 
     Parameters
     ----------
@@ -885,8 +739,7 @@ def generate_thumbnails(
     tmp_video_path: str
         The URI to the video file to generate thumbnails from.
     event: EventIngestionModel
-        The parent event of the session. If no captions are available,
-        speech context phrases will be pulled from the whole event details.
+        The parent event of the session.
     bucket: str
         The name of the GCS bucket to upload the produced audio to.
     credentials_file: str
@@ -962,12 +815,12 @@ def compile_session_processing_result(
     )
 
 
-def _process_person_ingestion(
+def _process_person_ingestion(  # noqa: C901
     person: ingestion_models.Person,
     default_session: Session,
     credentials_file: str,
     bucket: str,
-    upload_cache: Dict[str, db_models.Person] = {},
+    upload_cache: dict[str, db_models.Person] | None = None,
 ) -> db_models.Person:
     # The JSON string of the whole person tree turns out to be a great cache key because
     # 1. we can hash strings (which means we can shove them into a dictionary)
@@ -975,11 +828,16 @@ def _process_person_ingestion(
     # So, if the same person is referenced multiple times in the ingestion model
     # but most of those references have the same data and only a few have different data
     # the produced JSON string will note the differences and run when it needs to.
-    person_cache_key = person.to_json()  # type: ignore
+
+    # Create upload cache
+    if upload_cache is None:
+        upload_cache = {}
+
+    person_cache_key = person.to_json()
 
     if person_cache_key not in upload_cache:
         # Store person picture file
-        person_picture_db_model: Optional[db_models.File]
+        person_picture_db_model: db_models.File | None
         if person.picture_uri is not None:
             try:
                 tmp_person_picture_path = file_utils.resource_copy(
@@ -1050,7 +908,7 @@ def _process_person_ingestion(
         # Create seat
         if person.seat is not None:
             # Store seat picture file
-            person_seat_image_db_model: Optional[db_models.File]
+            person_seat_image_db_model: db_models.File | None
             try:
                 if person.seat.image_uri is not None:
                     tmp_person_seat_image_path = file_utils.resource_copy(
@@ -1100,7 +958,7 @@ def _process_person_ingestion(
             if person.seat.roles is not None:
                 for person_role in person.seat.roles:
                     # Create any bodies for roles
-                    person_role_body_db_model: Optional[db_models.Body]
+                    person_role_body_db_model: db_models.Body | None
                     if person_role.body is not None:
                         # Use or default role body start_datetime
                         if person_role.body.start_datetime is None:
@@ -1151,7 +1009,7 @@ def _process_person_ingestion(
 def _calculate_in_majority(
     vote: ingestion_models.Vote,
     event_minutes_item: ingestion_models.EventMinutesItem,
-) -> Optional[bool]:
+) -> bool | None:
     # Voted to Approve or Approve-by-abstention-or-absence
     if vote.decision in [
         db_constants.VoteDecision.APPROVE,
@@ -1177,9 +1035,9 @@ def _calculate_in_majority(
 
 
 @task
-def store_event_processing_results(
+def store_event_processing_results(  # noqa: C901
     event: EventIngestionModel,
-    session_processing_results: List[SessionProcessingResult],
+    session_processing_results: list[SessionProcessingResult],
     credentials_file: str,
     bucket: str,
 ) -> None:
@@ -1317,7 +1175,7 @@ def store_event_processing_results(
         )
 
     # Add event metadata
-    processed_person_upload_cache: Dict[str, db_models.Person] = {}
+    processed_person_upload_cache: dict[str, db_models.Person] = {}
     if event.event_minutes_items is not None:
         for emi_index, event_minutes_item in enumerate(event.event_minutes_items):
             if event_minutes_item.matter is not None:
@@ -1352,7 +1210,7 @@ def store_event_processing_results(
                         )
 
             else:
-                matter_db_model = None  # type: ignore
+                matter_db_model = None
 
             # Create minutes item
             minutes_item_db_model = db_functions.create_minutes_item(
@@ -1439,6 +1297,15 @@ def store_event_processing_results(
             # Add supporting files for matter and event minutes item
             if event_minutes_item.supporting_files is not None:
                 for supporting_file in event_minutes_item.supporting_files:
+                    try:
+                        file_uri = try_url(supporting_file.uri)
+                        supporting_file.uri = file_uri
+                    except LookupError as e:
+                        log.error(
+                            f"SupportingFile ('{supporting_file.uri}') "
+                            f"uri does not exist. Skipping. Error: {e}"
+                        )
+                        continue
 
                     # Archive as matter file
                     if event_minutes_item.matter is not None:
@@ -1452,7 +1319,10 @@ def store_event_processing_results(
                                 db_model=matter_file_db_model,
                                 credentials_file=credentials_file,
                             )
-                        except (FieldValidationFailed, ConnectionError) as e:
+                        except (
+                            FieldValidationFailed,
+                            ConnectionError,
+                        ) as e:
                             log.error(
                                 f"MatterFile ('{supporting_file.uri}') "
                                 f"could not be archived. Skipping. Error: {e}"
